pub fn parse_log_output(output: &str) -> LogParseResultExpand description
Parse jj log --template LOG_TEMPLATE output.
Skips malformed lines rather than failing, returning them in
LogParseResult::skipped for the caller to handle.
pub fn parse_log_output(output: &str) -> LogParseResultParse jj log --template LOG_TEMPLATE output.
Skips malformed lines rather than failing, returning them in
LogParseResult::skipped for the caller to handle.