Skip to main contentCrate vcs_runner
Source - Bookmark
- A jj bookmark with sync status.
- BookmarkParseResult
- Result of parsing bookmark output, including any skipped entries.
- GitRemote
- A git remote.
- LogEntry
- A jj log entry parsed from jj template JSON output.
- LogParseResult
- Result of parsing log output, including any skipped entries.
- RunOutput
- Captured output from a successful command.
- ConflictState
- Whether a jj commit has unresolved conflicts.
- ContentState
- Whether a jj commit is empty (no file changes).
- RemoteStatus
- Sync status of a bookmark relative to its remote.
- RunError
- Error type for subprocess execution.
- VcsBackend
- Which version control system is managing a directory.
- WorkingCopy
- Whether a jj commit is the current working copy.
- BOOKMARK_TEMPLATE
- jj template for
jj bookmark list producing line-delimited JSON. - LOG_TEMPLATE
- jj template for
jj log producing line-delimited JSON entries.
- binary_available
- Check whether a binary is available on PATH.
- binary_version
- Get a binary’s version string, if available.
- detect_vcs
- Detect the VCS backend for a path, without running any subprocesses.
- git_available
- Check whether the
git binary is available on PATH. - git_version
- Get the git version string, if available.
- is_transient_error
- Default transient error check for jj/git.
- jj_available
- Check whether the
jj binary is available on PATH. - jj_version
- Get the jj version string, if available.
- parse_bookmark_output
- Parse
jj bookmark list --template BOOKMARK_TEMPLATE output. - parse_log_output
- Parse
jj log --template LOG_TEMPLATE output. - parse_remote_list
- Parse
jj git remote list output into GitRemote values. - run_cmd
- Run an arbitrary command, capturing stdout and stderr.
- run_cmd_in
- Run an arbitrary command in a specific directory, capturing output.
- run_cmd_in_with_env
- Run a command in a specific directory with extra environment variables.
- run_cmd_inherited
- Run an arbitrary command with inherited stdout/stderr (visible to user).
- run_git
- Run a
git command in a repo directory, returning captured output. - run_git_with_retry
- Run a
git command with retry on transient errors. - run_jj
- Run a
jj command in a repo directory, returning captured output. - run_jj_with_retry
- Run a
jj command with retry on transient errors. - run_with_retry
- Run a command in a directory with retry on transient errors.